==> Shiira2.0src.zip: Shiira2.0src/shiira2/trunk/source/menu/SRDownloadContextMenu.m <==
/*
SRDownloadContextMenu.m

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import "SRDownloadContextMenu.h"

static NSMenu*  _s_contextMenu = nil;

@implementation SRDownloadContextMenu : NSObject

//--------------------------------------------------------------//
// Initialize
//--------------------------------------------------------------//

+ (void)_loadContextMenu
{
    // Load context menu
    SRDownloadContextMenu*  contextMenu;
    contextMenu = [[SRDownloadContextMenu alloc] init];
    if (![NSBundle loadNibNamed:@"DownloadContextMenu" owner:contextMenu]) {
        // Error
        NSLog(@"Could not load DownloadContextMenu.nib");
    }
}

- (void)awakeFromNib
{
    // Set to static variables
    _s_contextMenu = _contextMenu;
}

//--------------------------------------------------------------//
// Context menu
//--------------------------------------------------------------//

+ (NSMenu*)contextMenu
{
    if (!_s_contextMenu) {
        [self _loadContextMenu];
    }
    
    return _s_contextMenu;
}

@end

==> Shiira2.2src.zip: Shiira2.2src/shiira2/trunk/source/menu/SRDownloadContextMenu.m <==
/*
SRDownloadContextMenu.m

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import "SRDownloadContextMenu.h"

static NSMenu*  _s_contextMenu = nil;

@implementation SRDownloadContextMenu

//--------------------------------------------------------------//
// Initialize
//--------------------------------------------------------------//

+ (void)_loadContextMenu
{
    // Load context menu
    SRDownloadContextMenu*  contextMenu;
    contextMenu = [[SRDownloadContextMenu alloc] init];
    if (![NSBundle loadNibNamed:@"DownloadContextMenu" owner:contextMenu]) {
        // Error
        NSLog(@"Could not load DownloadContextMenu.nib");
    }
}

- (void)awakeFromNib
{
    // Set to static variables
    _s_contextMenu = _contextMenu;
}

//--------------------------------------------------------------//
// Context menu
//--------------------------------------------------------------//

+ (NSMenu*)contextMenu
{
    if (!_s_contextMenu) {
        [self _loadContextMenu];
    }
    
    return _s_contextMenu;
}

@end
